@@ -114,7 +114,6 @@ checkInputEstimateIncidence <- function(cdm,
                                         outcomeWashout,
                                         repeatedEvents,
                                         minCellCount,
-                                        temporary,
                                         returnParticipants) {
   cdmCheck(cdm)
 
@@ -132,14 +131,8 @@ checkInputEstimateIncidence <- function(cdm,
     add = errorMessage,
     null.ok = TRUE
   )
-  outcomeCheck <- outcomeTable %in% names(cdm)
-  checkmate::assertTRUE(outcomeCheck,
-    add = errorMessage
-  )
-  if (!isTRUE(outcomeCheck)) {
-    errorMessage$push(
-      "- `outcomeTable` is not found in cdm"
-    )
+  if(!outcomeTable %in% names(cdm)){
+    cli::cli_abort(paste0("outcomeTable ", outcomeTable, " is not found in cdm"))
   }
   outcomeAttributeCheck <- (!is.null(
     CDMConnector::cohort_count(cdm[[outcomeTable]])
@@ -172,8 +165,13 @@ checkInputEstimateIncidence <- function(cdm,
   checkmate::assert_logical(completeDatabaseIntervals,
     add = errorMessage
   )
+  if (any(is.null(outcomeWashout))) {
+    cli::cli_abort("outcomeWashout cannot be NULL")
+    }
   if (any(outcomeWashout != Inf)) {
     checkmate::assert_numeric(outcomeWashout[which(!is.infinite(outcomeWashout))],
+                              lower = 0, upper = 99999,
+                              null.ok = FALSE,
       add = errorMessage
     )
   }
@@ -181,15 +179,6 @@ checkInputEstimateIncidence <- function(cdm,
     add = errorMessage
   )
   checkmate::assert_number(minCellCount)
-  checkmate::assert_logical(temporary,
-    add = errorMessage
-  )
-  if (isTRUE(temporary)) {
-    # returnParticipants only when we are using permanent tables
-    checkmate::assert_false(returnParticipants,
-      add = errorMessage
-    )
-  }
   checkmate::assert_logical(returnParticipants,
     add = errorMessage
   )
@@ -226,7 +215,6 @@ checkInputEstimatePrevalence <- function(cdm,
                                          fullContribution,
                                          timePoint,
                                          minCellCount,
-                                         temporary,
                                          returnParticipants) {
   cdmCheck(cdm)
 
@@ -292,18 +280,9 @@ checkInputEstimatePrevalence <- function(cdm,
   checkmate::assert_logical(completeDatabaseIntervals,
     add = errorMessage
   )
-  checkmate::assert_logical(temporary,
-    add = errorMessage
-  )
   checkmate::assert_logical(returnParticipants,
     add = errorMessage
   )
-  if (isTRUE(temporary)) {
-    # returnParticipants only when we are using permanent tables
-    checkmate::assert_false(returnParticipants,
-      add = errorMessage
-    )
-  }
   return(checkmate::reportAssertions(collection = errorMessage))
 }
 
